import TerserPlugin from 'terser-webpack-plugin';

import utils from './utils';
import webpack from 'webpack';

export default function getOptimization() {
    let baseOptim: webpack.Options.Optimization = {
        runtimeChunk: {
            name: 'runtime'
        }
    };

    if (utils.isProduction()) {
        baseOptim = Object.assign({}, baseOptim, {
            splitChunks: {
                chunks: 'all',
                name: false
            },
            minimize: true,
            minimizer: [new TerserPlugin({
                extractComments: false,
                terserOptions: {
                    output: {
                        comments: false,
                        ascii_only: true
                    }
                }
            })]
        });
    }

    if (utils.isDev()) {
        baseOptim = Object.assign({}, baseOptim, {
            splitChunks: {
                chunks: 'all',
                name: false,
                cacheGroups: {
                    vendor: {
                        test: /[\\/]node_modules[\\/]/,
                        name: 'vendor.js'
                    }
                }
            },
        });
    }

    return baseOptim;
};
